#
# spec file for package python-maturin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-maturin
Version:        1.9.0
Release:        1.1
Summary:        Rust/Python Interoperability
License:        Apache-2.0 OR MIT
URL:            https://github.com/PyO3/maturin
Source:         https://files.pythonhosted.org/packages/source/m/maturin/maturin-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools-rust >= 1.4.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tomli >= 1.1.0 if %python-base < 3.11}
BuildRequires:  %{python_module wheel >= 0.36.2}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?python_version_nodots} < 311
Requires:       python-tomli >= 1.1.0
%endif
%python_subpackages

%description
Build and publish crates with pyo3, cffi and uniffi bindings
as well as rust binaries as python packages.

It supports building wheels for Python 3.8+, can upload them
to PyPI and has basic PyPy and GraalPy support.

%prep
%autosetup -a1 -p1 -n maturin-%{version}
sed -i '1{/env python/d}' maturin/__init__.py
sed -i 's/--locked/--offline/' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/maturin

%check

%post
%python_install_alternative maturin

%postun
%python_uninstall_alternative maturin

%files %{python_files}
%license license-apache license-mit
%doc Changelog.md README.md
%python_alternative %{_bindir}/maturin
%{python_sitearch}/maturin
%{python_sitearch}/maturin-%{version}.dist-info

%changelog
* Tue Jun 24 2025 Mia Herkt <mia@0x0.st>
- Update to 1.9.0
  * Update pyproject-toml to 0.13.5
    gh#PyO3/maturin#2645
  * Fix clippy lints
    gh#PyO3/maturin#2648
  * ZipWriter requires a compression level of None for the stored
    method
    gh#PyO3/maturin#2644
  * Implement PEP 639 Support
    gh#PyO3/maturin#2647
  * Don't go through Display for platform tag to policy
    gh#PyO3/maturin#2652
  * Add --compatibility pypi to avoid building for unsupported
    architectures
    gh#PyO3/maturin#2650
  * Fix self bootstrap without Rust installed
    gh#PyO3/maturin#2653
* Mon Jun  9 2025 Mia Herkt <mia@0x0.st>
- Update to 1.8.7
  * Allow specifying compression method and level, in both `build`
    and `develop` modes
    gh#PyO3/maturin#2625
* Tue May 13 2025 Mia Herkt <mia@0x0.st>
- Update to 1.8.6
  * Print a message when overriding platform tag from
    `_PYTHON_HOST_PLATFORM`
    gh#PyO3/maturin#2594
  * Use the current python interpreter's version when the abi3
    feature is set with no explicit version
    gh#PyO3/maturin#2597
* Fri May  9 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 1.8.4
  * Install a Rust toolchain into a temporary directory when building maturin
    itself or a package and a Rust toolchain is missing. Set
    MATURIN_NO_INSTALL_RUST to disable this behavior. #2421
  * Fix broken maturin develop with latest uv in #2584
  * Add PYO3_PYTHON env var support in #2534
  * Sort RECORD file in wheel archives to make them deterministic in #2550
  * Publish wheel for loongarch64 in #2548
  * Add --compression-level option to build command in #2572
* Sun Mar 16 2025 Mia Herkt <mia@0x0.st>
- Update to 1.8.3
  * Fix cargo run uniffi-bindgen when cross compiling
    gh#PyO3/maturin#2476
  * Add rnet python library to examples
    gh#PyO3/maturin#2480
  * bump the attest-build-provenance version in the generated ci file
    gh#PyO3/maturin#2484
  * Auto detect PyPy 3.11
    gh#PyO3/maturin#2487
  * Update manylinux/musllinux policies to the latest main
    gh#PyO3/maturin#2491
  * Update generate-ci options in user guide
    gh#PyO3/maturin#2501
  * chore: Update cbindgen to 0.28.0
    gh#PyO3/maturin#2498
  * Don't install dependencies when running maturin develop --skip-install
    gh#PyO3/maturin#2504
  * Upgrade pyo3 to 0.24.0
    gh#PyO3/maturin#2511
  * Update the TP docs to use pypi as the GH Env name
    gh#PyO3/maturin#2512
  * fix auditwheel .so relocation for namespace modules
    gh#PyO3/maturin#2513
  * Updates Rng legacy methods in tutorial
    gh#PyO3/maturin#2514
* Sat Feb  8 2025 Dirk Müller <dmueller@suse.com>
- update to 1.8.2:
  * Exclude packages not in the dependency tree when finding
    bindings in #2426
  * Use uv automatically when running maturin develop inside uv-
    created virtualenv in #2433
  * Consider abi3 minor version when resolving Python
    interpreters in #2437
  * Handle archived dylibs on AIX in #2442
  * Fix unnecessary rebuilds due to pyo3 config file modified
    time change in #2446
  * Fix the name of the .data directory in the generated wheel in
    [#2449]
  * Update minimal manylinux version for loongarch64 in #2451
* Fri Jan  3 2025 Markéta Machová <mmachova@suse.com>
- Update to 1.8.1
  * Downgrade invalid version info in `pyproject.toml` error to
    warning in #2417
  * Make `maturin develop` fail if version info is invalid in
    pyproject.toml in #2418
  * Don't add wheel data to sdist in #2367
  * Add sparcv9 architecture support in #2380
  * Properly handle dynamic version in pyproject.toml in #2391
  * Fix xwin cross compile on non-Windows system in #2391
  * Fix interpreter selection for abi3 bindings in #2392
  * Use the official recommended naming pattern for cffi module
    file in #2406
  * Add Linux armv5te architecture support in #2409
  * Only build Python 3.13t wheels by default for `pyo3` 0.23+ in
    [#2413]
* Wed Dec 18 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.7.8
  * Fix aarch64 Windows cross compilation by @messense in #2359
- Release 1.7.7
  * fix abi3 interpreter discovery on Windows by @davidhewitt in
    [#2333]
  * fix: remove extra indent in generated CI by @jsstevenson in
    [#2340]
  * Upgrade cargo-xwin to unify rustls versions by @kornelski in
    [#2222]
  * Normalize python source directory path by @messense in #2343
  * Enable fat LTO for maturin release workflow by @messense in
    [#2344]
  * Use different binding dirs for different uniffi modules by
    @messense in #2348
  * Update minimal Python minor version for pyo3 0.23 by @messense
    in #2350
  * Limit minimal PyPy version based on bindings crate version by
    @messense in #2351
  * Remove hard coded pip show in fix_direct_url by @mbway in #2352
  * Do not use xwin to compile on Windows when MSVC compiler can
    build for the target by @messense in #2353
- Release 1.7.6
  * allow -i 3.13t by @davidhewitt in #2324
  * propagate abiflags to wheel name on Windows by @davidhewitt in
  [#2325]
  * Add free-threaded wheel build to generate-ci by default by
  @messense in #2329
  * Bump metadata version to 2.4 to fix license bug by @konstin in
  [#2332]
- Release 1.7.5
  * Auto detect Python 3.13 by @messense in #2248
  * feat: add skip attestation option to maturin ci github by
  @moldhouse in #2254
  * generate-ci: use macos-13 runner for x86_64 build job by
  @messense in #2255
  * Improve wheel reproducibility by sorting libs by @ycongal-smile
  in #2261
  * Fix inverted workspace inclusions by @konstin in #2262
  * Fix broken links to PyO3 building docs by @laurentS in #2270
  * Update goblin to 0.9 by @musicinmybrain in #2284
  * Don't resolve python interpreter when building sdist only by
  @messense in #2292
  * include timestamps in the suggested log format by @mbway in
  [#2304]
  * Add support for GNU/Hurd by @sthibaul in #2306
  * Fix __init__ exports when using multiple UniFFI bindings by
  @Nickersoft in #2305
  * Add free-threaded Python support by @messense in #2310
- Fix _service file for cargo_vendor
- Update description
* Sat Sep 28 2024 Mia Herkt <mia@0x0.st>
- Update to 1.7.4
  * Fix musllinux rpath for non-cffi bindings
    gh#PyO3/maturin#2233
- Changes in 1.7.3:
  * Fix pypi/testpypi upload
    gh#PyO3/maturin#2229
- Changes in 1.7.2:
  * Split out test-windows-cross to speed up ci
    gh#PyO3/maturin#2188
  * Upgrade cargo-deny
    gh#PyO3/maturin#2200
  * Cross building fixes
    gh#PyO3/maturin#2204
  * UniFFI: supports bindings generated from multiple crates
    gh#PyO3/maturin#2208
  * doc: add -r/--release flag info to tutorial
    gh#PyO3/maturin#2211
  * Enable --all-features when building source distribution
    gh#PyO3/maturin#2215
  * Replace "." with "/" in module_name
    gh#PyO3/maturin#2219
* Sun Aug 25 2024 Mia Herkt <mia@0x0.st>
- Update to 1.7.1
  * Update clap_complete_command to v0.6.1
    gh#PyO3/maturin#2144
  * Fix platform tags when cross-compiling universal2
    gh#PyO3/maturin#2153
  * Fix Typo in Migration Guide
    gh#PyO3/maturin#2162
  * Fix rust 1.80 clippy errors
    gh#PyO3/maturin#2164
  * Don't check .gitignore files in parent directories
    gh#PyO3/maturin#2158
  * Replace --skip-auditwheel with --auditwheel option
    gh#PyO3/maturin#2165
  * Remove install_requires and setup_requires from setup.py
    gh#PyO3/maturin#2171
  * Use modern stripping option
    gh#PyO3/maturin#2173
  * Move project metadata from setup.py to pyproject.toml
    gh#PyO3/maturin#2175
  * Update manylinux/musllinux policies to the latest main
    gh#PyO3/maturin#2178
  * use just licenses as the license directory in a wheel
    gh#PyO3/maturin#2181
  * Forward cargo package --list warnings
    gh#PyO3/maturin#2186
  * Add current package context to source dist error
    gh#PyO3/maturin#2187
  * Place source dist readmes next to Cargo.toml
    gh#PyO3/maturin#2184
* Sun Jul  7 2024 Mia Herkt <mia@0x0.st>
- Update to 1.7.0
  * Expose env variable to suppress build backend warning
    gh#PyO3/maturin#2099
  * Canonicalize base executable path in PEP 517 build
    gh#PyO3/maturin#2100
  * Initial iOS support
    gh#PyO3/maturin#2102
  * Remove old import hook
    gh#PyO3/maturin#2105
  * Bump MSRV to 1.74.0
    gh#PyO3/maturin#2108
  * Upgrade pyo3 to 0.22.0, uniffi to 0.28.0
    gh#PyO3/maturin#2121
  * Override wheel tag with _PYTHON_HOST_PLATFORM
    gh#PyO3/maturin#2122
  * Update cargo-xwin to 0.16.5
    gh#PyO3/maturin#2123
  * Don't add duplicate files
    gh#PyO3/maturin#2125
  * Docs: Fix Typo in Verb Conjugation
    gh#PyO3/maturin#2129
  * pep517: only use base python when
    MATURIN_PEP517_USE_BASE_PYTHON env var is set
    gh#PyO3/maturin#2134
* Tue Jun  4 2024 Mia Herkt <mia@0x0.st>
- Update to 1.6.0
  * Add pypi name validation
    gh#PyO3/maturin#2007
  * Add JSON schema generation
    gh#PyO3/maturin#2005
  * Detect compiling from Linux gnu to Linux musl as cross compiling
    gh#PyO3/maturin#2010
  * Upgrade uniffi to 0.27.0
    gh#PyO3/maturin#2021
  * Add instrumentation support for develop
    gh#PyO3/maturin#2019
  * Make tracing-subscriber mandatory
    gh#PyO3/maturin#2022
  * Import hook upgrade
    gh#PyO3/maturin#2024
  * Add uv as develop backend command
    gh#PyO3/maturin#2015
  * Also try uv in PATH in develop --uv
    gh#PyO3/maturin#2026
  * docs: update pyo3 to match tutorial
    gh#PyO3/maturin#2029
  * Add support for AIX
    gh#PyO3/maturin#2030
  * Remove rust-cpython from project init/new template
    gh#PyO3/maturin#2034
  * Only run uv tests on platforms that has wheel on PyPI or when uv bina…
    gh#PyO3/maturin#2037
  * Install cffi and uv on demand in test_develop
    gh#PyO3/maturin#2043
  * Add support for wasm32-wasip1 and wasm32-wasip2 targets
    gh#PyO3/maturin#2054
  * fix: windows exit code with python
    gh#PyO3/maturin#2055
  * Remove rust-cpython support from documentation
    gh#PyO3/maturin#2057
  * docs: Add bleuscore in examples
    gh#PyO3/maturin#2061
  * Fix new clippy warnings on Rust 1.78.0
    gh#PyO3/maturin#2065
  * Allows to use Maturin with ziglang 0.11 and 0.12
    gh#PyO3/maturin#2067
  * Show full path in missing readme error message
    gh#PyO3/maturin#2074
  * Update cargo mock deps
    gh#PyO3/maturin#2075
  * Ban std::fs trough clippy
    gh#PyO3/maturin#2076
  * Preserve file permission when copying
    gh#PyO3/maturin#2069
  * Detect target based on interpreter for pep517 build-wheel
    gh#PyO3/maturin#2088
  * Add a global verbose option
    gh#PyO3/maturin#2080
  * Use base executable when possible in PEP 517 build
    gh#PyO3/maturin#2094
  * Remove support for rust-cpython
    gh#PyO3/maturin#2044
* Thu Mar 28 2024 Mia Herkt <mia@0x0.st>
- Update to 1.5.1
  * fix changelog link
    gh#PyO3/maturin#1990
  * in pep517 build default compatibility to off instead of always specifying
    gh#PyO3/maturin#1992
  * Fix typo on maturin docs
    gh#PyO3/maturin#1997
  * Fix upload returning malformed summary error
    gh#PyO3/maturin#2002
* Sun Mar 17 2024 Mia Herkt <mia@0x0.st>
- Update to 1.5.0
  * tutorial: fix abi to match comment
    gh#PyO3/maturin#1876
  * Allow identical VIRTUAL_ENV and CONDA_PREFIX env vars
    gh#PyO3/maturin#1879
  * Upgrade pyo3 to 0.20
    gh#PyO3/maturin#1881
  * Skip directory when adding license files to wheel
    gh#PyO3/maturin#1890
  * Reject -i python when cross compiling
    gh#PyO3/maturin#1891
  * simplified clear-cache github action
    gh#PyO3/maturin#1897
  * Support uniffi-bindgen in cargo workspaces
    gh#PyO3/maturin#1909
  * Upgrade globlin to 0.8.0
    gh#PyO3/maturin#1912
  * Update **Note** to [!NOTE] in README
    gh#PyO3/maturin#1917
  * Match dependency readmes
    gh#PyO3/maturin#1915
  * Update some actions version in generate ci cli
    gh#PyO3/maturin#1916
  * Use extension name as library name, instead of hardcoded 'native.so'
    gh#PyO3/maturin#1918
  * Bump MSRV to 1.70
    gh#PyO3/maturin#1923
  * Remove setuptools-rust and milksnake mentions from readme
    gh#PyO3/maturin#1926
  * Upgrade uniffi to 0.26.0
    gh#PyO3/maturin#1927
  * Use M1 runner on GitHub Actions
    gh#PyO3/maturin#1928
  * Upgrade rustls to 0.22
    gh#PyO3/maturin#1929
  * Add extra note to "Using PyPI's trusted publishing" section.
    gh#PyO3/maturin#1939
  * Update pep440_rs, pep508_rs and pyproject-toml
    gh#PyO3/maturin#1945
  * Add support for configuring xwin using env vars
    gh#PyO3/maturin#1961
  * Put dynamic field under project instead of project.optional-dependencies
    gh#PyO3/maturin#1963
  * Revert "Auto detect Python 3.13"
    gh#PyO3/maturin#1964
  * Add validation for crate/package name in new/init
    gh#PyO3/maturin#1943
  * Update upload-artifact and download-artifact actions to v4
    gh#PyO3/maturin#1967
  * Add 32-bit RISC-V support
    gh#PyO3/maturin#1969
  * Isolated import hook changes
    gh#PyO3/maturin#1958
  * Fix feature = "cargo-clippy" deprecation
    gh#PyO3/maturin#1970
  * Adjust cbindgen Overrides for CFFI
    gh#PyO3/maturin#1957
  * Update to Metadata 2.3 to create reliable source dist metadata
    gh#PyO3/maturin#1965
  * Only set rustflags when necessary
    gh#PyO3/maturin#1978
* Mon Dec 11 2023 Mia Herkt <mia@0x0.st>
- Update to 1.4.0
  * Fix two tiny typos in README.md!
    gh#PyO3/maturin#1853
  * Bump MSRV to 1.67
    gh#PyO3/maturin#1847
  * Tiny tweak: Use Rust markdown block
    gh#PyO3/maturin#1855
  * Recommend using pipx to install maturin
    gh#PyO3/maturin#1859
  * [pre-commit.ci] pre-commit autoupdate
    gh#PyO3/maturin#1860
  * Update cargo-options to 0.7.1
    gh#PyO3/maturin#1862
  * Add support for cross compiling with cross
    gh#PyO3/maturin#1865
  * Bump the crates-io group with 8 updates
    gh#PyO3/maturin#1866
  * [pre-commit.ci] pre-commit autoupdate
    gh#PyO3/maturin#1867
  * Bump openssl from 0.10.59 to 0.10.60
    gh#PyO3/maturin#1868
  * Bump actions/github-script from 6 to 7
    gh#PyO3/maturin#1873
  * Bump conda-incubator/setup-miniconda from 2 to 3
    gh#PyO3/maturin#1872
  * Bump mymindstorm/setup-emsdk from 12 to 13
    gh#PyO3/maturin#1871
  * Update rustls-pemfile to 2.0.0
    gh#PyO3/maturin#1874
* Tue Nov 14 2023 Mia Herkt <mia@0x0.st>
- Update to 1.3.2
  * Switch to Ruff formatter
    gh#PyO3/maturin#1817
  * Upgrade ring to 0.17
    gh#PyO3/maturin#1819
  * Un-deprecate MATURIN_PEP517_ARGS env var
    gh#PyO3/maturin#1820
  * Add support for uniffi library mode
    gh#PyO3/maturin#1729
  * Fix missing member in Cargo.toml for sdist of nested workspace
    layout
    gh#PyO3/maturin#1828
  * Metadata: escape display name in email addresses
    gh#PyO3/maturin#1832
  * Fix rewriting workspace Cargo.toml in sdist
    gh#PyO3/maturin#1841
  * Fix glob workspace members matching in sdist
    gh#PyO3/maturin#1846
  * Add sdist tests for well-known downstream repositories
    gh#PyO3/maturin#1849
* Mon Nov  6 2023 Mia Herkt <mia@0x0.st>
- Update to 1.3.1
  * Use external uniffi-bindgen if no root package is configured
    gh#PyO3/maturin#1797
  * Add trusted publishing section to the user guide
    gh#PyO3/maturin#1800
  * Fix wheel filename for GraalPy
    gh#PyO3/maturin#1802
  * Pytest skeleton in mixed template
    gh#PyO3/maturin#1807
  * Keep trailing newlines from templates
    gh#PyO3/maturin#1808
  * Bump rustix from 0.37.23 to 0.37.25
    gh#PyO3/maturin#1809
  * Auto detect Python 3.13
    gh#PyO3/maturin#1810
  * Fix missing workspace.members in sdist
    gh#PyO3/maturin#1811
  * Don't set MACOSX_DEPLOYMENT_TARGET for editable builds
    gh#PyO3/maturin#1815
* Mon Oct  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.3.0
  * Refactor Cargo sdist generator to avoid rewriting local
    dependencies in gh#PyO3/maturin#1741
  * Added --pip-path argument to develop command in
    gh#PyO3/maturin#1753
  * Ignore sdist output files when building sdist in
    gh#PyO3/maturin#1756
  * Use python.exe by default in build command on Windows in
    gh#PyO3/maturin#1757
  * Don't require uniffi-bindgen to be installed for uniffi
    bindings in gh#PyO3/maturin#1762
  * Fix platform tag for graalpy in gh#PyO3/maturin#1773
  * Always set minor version to 0 when major version >= 11 for
    macOS in gh#PyO3/maturin#1778
  * Warning about incorrect maturin version pyproject.toml
    [build-system] requires in gh#PyO3/maturin#1793
- Release 1.2.3 - 2023-08-17
  * Fix sdist build failure with workspace path dependencies by
    HerringtonDarkholme in gh#PyO3/maturin#1739
- Release 1.2.2 - 2023-08-14
  * Fix non interactive mode check when username/password was
    supplied from cli in gh#PyO3/maturin#1737
- Release 1.2.1 - 2023-08-14
  * Add non-interactive mode to upload command in
    gh#PyO3/maturin#1722
  * Fix link-native-libraries check for emscripten target in
    gh#PyO3/maturin#1724
  * Add support for ALL_PROXY to upload command in
    gh#PyO3/maturin#1727
  * Handle renamed Rust dependency in sdist in gh#PyO3/maturin#1728
  * Fix invalid TOML when rewriting workspace inherited
    dependencies in gh#PyO3/maturin#1733
- Release 1.2.0 - 2023-08-06
  * Add basic support for implicit namespaces gh#PyO3/maturin#1645
  * Add Linux mips64 and mips architecture support in
    gh#PyO3/maturin#1712
  * Add x86_64h-apple-darwin target support in gh#PyO3/maturin#1717
* Sun Jun 11 2023 Mia Herkt <mia@0x0.st>
- Update to v1.1.0:
  * Add basic support for GraalPy
    gh#PyO3/maturin#1645
  * Refactor abi tag to use `EXT_SUFFIX`
    gh#PyO3/maturin#1648
  * Add Linux loongarch64 architecture support
    gh#PyO3/maturin#1653
  * Add `--skip-install` option to `maturin develop`
    gh#PyO3/maturin#1654
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun May 28 2023 Mia Herkt <mia@0x0.st>
- Update to v1.0.1:
  * Add Python 3.12 sysconfigs
    gh#PyO3/maturin#1629
  * refactor: generate well known sysconfigs in code
    gh#PyO3/maturin#1633
  * Upgrade dirs to 5.0
    gh#PyO3/maturin#1634
  * Fix panicking when no cargo build targets are selected
    gh#PyO3/maturin#1635
  * Upgrade platform-info to 2.0, base64 to 0.21
    gh#PyO3/maturin#1631
- Changes in v1.0.0:
  * Add support for multiple --config-settings in PEP517 backend
    gh#PyO3/maturin#1624
  * Remove deprecated --universal2 cli option
    gh#PyO3/maturin#1620
* Sun May 21 2023 Mia Herkt <mia@0x0.st>
- Update to v0.15.3:
  * Fix cross-compile to Apple universal2 in the other platform
    gh#PyO3/maturin#1613
  * Remove serde(flatten) to improve error messages
    gh#PyO3/maturin#1616
  * Allow syn 2.0
    gh#PyO3/maturin#1617
  * describe the need for module-name
    gh#PyO3/maturin#1604
  * Add PEP 517 config_settings support
    gh#PyO3/maturin#1619
  * Keep file mode on Unix
    gh#PyO3/maturin#1622
- Changes in v0.15.2:
  * Remove bors
    gh#PyO3/maturin#1602
  * When determining the python module name, use pyproject.toml
    project.name over Cargo.toml package.name.
    gh#PyO3/maturin#1608
  * Warn on missing python-source contents
    gh#PyO3/maturin#1607
  * Fix rewriting dev-dependencies in sdist
    gh#PyO3/maturin#1610
* Mon May  8 2023 Mia Herkt <mia@0x0.st>
- Update to v0.15.1:
  * Use shlex to split MATURIN_SETUP_ARGS
    gh#PyO3/maturin#1595
  * Fix finding interpreters from bundled sysconfigs
    gh#PyO3/maturin#1598
- Changes in v0.15.0:
  * Feature gate zig and xwin based cross compiling
    gh#PyO3/maturin#1324
  * Feature gate maturin new and maturin init commands
    gh#PyO3/maturin#1330
  * Build with --no-default-features
    gh#PyO3/maturin#1333
  * Support SOURCE_DATE_EPOCH environment variable in wheel
    building
    gh#PyO3/maturin#1334
  * Remove deprecated config options
    gh#PyO3/maturin#1335
  * cargo deny multiple crate versions
    gh#PyO3/maturin#1336
  * Replace rpassword with dialoguer
    gh#PyO3/maturin#1338
  * Fix sdist when all Cargo workspace members are excluded
    gh#PyO3/maturin#1343
  * Update normpath to 1.0.0
    gh#PyO3/maturin#1348
  * Update bundled Linux sysconfig
    gh#PyO3/maturin#1349
  * Allow Rust crate to be placed outside of the directory
    containing pyproject.toml
    gh#PyO3/maturin#1347
  * Update minijina to 0.27.0
    gh#PyO3/maturin#1350
  * Run uniffi-bindgen command instead of depending on
    uniffi_bindgen crates
    gh#PyO3/maturin#1352
  * Disallow uniffi bin bindings
    gh#PyO3/maturin#1353
  * Clarify --interpreter value
    gh#PyO3/maturin#1358
  * Update uniffi_bindgen to 0.22.0 in test crates
    gh#PyO3/maturin#1360
  * Add workspace lock file to sdist as a fallback
    gh#PyO3/maturin#1362
  * Update cargo-xwin to 0.13.3
    gh#PyO3/maturin#1363
  * Update toml_edit to 0.16.0
    gh#PyO3/maturin#1373
  * Update cargo-zigbuild to 0.14.3
    gh#PyO3/maturin#1375
  * Update console to 0.15.3
    gh#PyO3/maturin#1379
  * Add support for packaging multiple pure Python packages
    gh#PyO3/maturin#1378
  * Detect src-layout for pure Rust projects with multiple Python
    packages
    gh#PyO3/maturin#1380
  * Fallback to sysconfig interpreters for pyo3 bindings
    gh#PyO3/maturin#1381
  * Bump psf/black from 22.10.0 to 22.12.0
    gh#PyO3/maturin#1384
  * Bump sigstore/gh-action-sigstore-python from 0.1.0 to 0.2.0
    gh#PyO3/maturin#1385
  * chore: cargo update ureq and console
    gh#PyO3/maturin#1386
  * Update pyodide to 0.22.0
    gh#PyO3/maturin#1387
  * Remove unnecessary ruff excludes
    gh#PyO3/maturin#1388
  * Remove confusing libpython.so from cross compile error message
    gh#PyO3/maturin#1389
  * Add MSRV configuration for clippy
    gh#PyO3/maturin#1391
  * Update toml_edit to 0.17.1, minijinja to 0.28.0
    gh#PyO3/maturin#1392
  * Don't pass MACOSX_DEPLOYMENT_TARGET when query default value
    from rustc
    gh#PyO3/maturin#1395
  * Update cargo-xwin to 0.13.5
    gh#PyO3/maturin#1396
  * Update trycmd to 0.14.10
    gh#PyO3/maturin#1401
  * Add link to bindings guide in new and init commands
    gh#PyO3/maturin#1403
  * Update schannel to remove outdated windows-sys 0.36 dependency
    gh#PyO3/maturin#1404
  * Respect rustflags settings in cargo configuration file
    gh#PyO3/maturin#1405
  * Run cargo deny check for Windows and macOS
    gh#PyO3/maturin#1408
  * Add Cargo compile targets configuration for filtering multiple
    bin targets
    gh#PyO3/maturin#1339
  * Use module name specified
    gh#PyO3/maturin#1409
  * Update minijinja to 0.29.0
    gh#PyO3/maturin#1414
  * Use the extension_name in develop builds
    gh#PyO3/maturin#1416
  * Upgrade pyo3 to 0.18.0
    gh#PyO3/maturin#1417
  * Update minijinja to 0.30.0
    gh#PyO3/maturin#1420
  * Completing type hints for python files
    gh#PyO3/maturin#1421
  * Dockerfile: Install openssh-client to be able to fetch git
    dependencies
    gh#PyO3/maturin#1427
  * Fix clippy warnings on Rust 1.67.0
    gh#PyO3/maturin#1428
  * Better error message when normalize path failed
    gh#PyO3/maturin#1432
  * Add a user-friendly panic hook
    gh#PyO3/maturin#1436
  * readme: provide needed pauses
    gh#PyO3/maturin#1437
  * Don't package dev-only path dependencies in sdist
    gh#PyO3/maturin#1435
  * Use Rust beta channel to test Cargo sparse index protocol
    gh#PyO3/maturin#1440
  * Keep dev-dependencies in sdist when there are no path
    dependencies
    gh#PyO3/maturin#1441
  * Update toml_edit to 0.19 and switch back to toml for parsing
    gh#PyO3/maturin#1439
  * Bump ignore from 0.4.19 to 0.4.20
    gh#PyO3/maturin#1445
  * Bump cargo_metadata from 0.15.2 to 0.15.3
    gh#PyO3/maturin#1444
  * Bump docker/build-push-action from 3 to 4
    gh#PyO3/maturin#1449
  * Bump sigstore/gh-action-sigstore-python from 0.2.0 to 1.1.0
    gh#PyO3/maturin#1452
  * Bump mymindstorm/setup-emsdk from 11 to 12
    gh#PyO3/maturin#1450
  * Bump psf/black from 22.12.0 to 23.1.0
    gh#PyO3/maturin#1451
  * Update cargo-options to 0.6.0
    gh#PyO3/maturin#1454
  * Update zip to 0.6.4
    gh#PyO3/maturin#1455
  * Deprecate --universal2 in favor of universal2-apple-darwin
    target
    gh#PyO3/maturin#1457
  * Check path-like interpreter arguments when cross compiling
    gh#PyO3/maturin#1459
  * Fix new cargo deny errors
    gh#PyO3/maturin#1466
  * Fix link to ballista
    gh#PyO3/maturin#1469
  * Add bin bindings support to generate-ci command
    gh#PyO3/maturin#1470
  * Raise an error when Cargo.toml contains removed python package
    metadata
    gh#PyO3/maturin#1471
  * Update cargo-zigbuild to 0.16.0
    gh#PyO3/maturin#1474
  * Detect .venv in current or parent folder in maturin develop
    gh#PyO3/maturin#1462
  * Use extension_name instead of module_name for CFFI extensions
    in develop mode
    gh#PyO3/maturin#1476
  * Update thread_local to 1.1.7 and minijina to 0.30.3
    gh#PyO3/maturin#1478
  * Enable extension-module feature in pyproject.toml in project
    templates
    gh#PyO3/maturin#1479
  * Add support for uniffi 0.23
    gh#PyO3/maturin#1481
  * Feature-gate command line completions
    gh#PyO3/maturin#1486
  * Add support for linking with pyo3 in abi3 debug mode on Windows
    gh#PyO3/maturin#1487
  * Add support for custom TLS certificate authority bundle
    gh#PyO3/maturin#1483
  * Use default ext_suffix for Emscripten target if not provided in
    PYO3_CONFIG_FILE
    gh#PyO3/maturin#1491
  * Upgrade keyring to 2.0.0
    gh#PyO3/maturin#1331
  * chore: Update some dependencies
    gh#PyO3/maturin#1497
  * Update cargo-zigbuild to 0.16.1
    gh#PyO3/maturin#1499
  * Use keyutils instead of secret-service for accessing Linux
    keyring
    gh#PyO3/maturin#1500
  * Update cargo-zigbuild to 0.16.2
    gh#PyO3/maturin#1501
  * Fix installation message for uniffi-bindgen
    gh#PyO3/maturin#1502
  * Build maturin with native-tls support on aarch64 Windows
    gh#PyO3/maturin#1503
  * refactor: use stderr for human readable output
    gh#PyO3/maturin#1504
  * Add sdist support to generate-ci
    gh#PyO3/maturin#1505
  * Bump sigstore/gh-action-sigstore-python from 1.1.0 to 1.2.1
    gh#PyO3/maturin#1511
  * Bump goblin from 0.6.0 to 0.6.1
    gh#PyO3/maturin#1508
  * Fine-grained GitHub Actions permission in generate-ci
    gh#PyO3/maturin#1513
  * Update crossbeam-*
    gh#PyO3/maturin#1514
  * Update msi to 0.5.1
    gh#PyO3/maturin#1518
  * use the official sccache-action repo
    gh#PyO3/maturin#1519
  * Update cargo-zigbuild to 0.16.3
    gh#PyO3/maturin#1523
  * Fix module name when it's specified in
    package.metadata.maturin.name
    gh#PyO3/maturin#1524
  * Only check for minus in extension name
    gh#PyO3/maturin#1526
  * Bump MSRV to 1.64.0
    gh#PyO3/maturin#1528
  * Update cargo-zigbuild to 0.16.4
    gh#PyO3/maturin#1527
  * Bump openssl from 0.10.45 to 0.10.48
    gh#PyO3/maturin#1530
  * Add support for target specific build configuration
    gh#PyO3/maturin#1536
  * Update wasmtime dependency version to 7.0.0
    gh#PyO3/maturin#1538
  * Update pyproject-toml to 0.4.0
    gh#PyO3/maturin#1539
  * Fix typo in project_layout.md docs
    gh#PyO3/maturin#1542
  * Update cargo-zigbuild to 0.16.5
    gh#PyO3/maturin#1544
  * Update pyodide to 0.23.0
    gh#PyO3/maturin#1549
  * Bump sigstore/gh-action-sigstore-python from 1.2.1 to 1.2.3
    gh#PyO3/maturin#1555
  * Bump mozilla-actions/sccache-action from 0.0.1 to 0.0.3
    gh#PyO3/maturin#1556
  * docs: do not tell users to put classifiers in Cargo.toml
    gh#PyO3/maturin#1557
  * Bump psf/black from 23.1.0 to 23.3.0
    gh#PyO3/maturin#1554
  * Use pep440_rs and pep508_rs
    gh#PyO3/maturin#1558
  * Fix wrong EXT_SUFFIX when cross compiling musllinux wheels for
    Python 3.11
    gh#PyO3/maturin#1560
  * chore: cargo update
    gh#PyO3/maturin#1562
  * Update cargo-zigbuild to 0.16.7
    gh#PyO3/maturin#1567
  * Fix module_writers::write_python_part include target check
    gh#PyO3/maturin#1573
  * Rewrite platform specific dependencies in Cargo.toml
    gh#PyO3/maturin#1572
  * Fix two sdist issues
    gh#PyO3/maturin#1577
  * Document binary and library in a single package
    gh#PyO3/maturin#1565
  * Add trusted publisher support
    gh#PyO3/maturin#1578
  * Bump target-lexicon to 0.12.7
    gh#PyO3/maturin#1579
  * Bump peter-evans/create-pull-request from 4 to 5
    gh#PyO3/maturin#1582
  * Update pyproject-toml to 0.6.0
    gh#PyO3/maturin#1585
  * Fix maturin failing to handle empty sysroot
    gh#PyO3/maturin#1589
  * Introduce git source distribution generator
    gh#PyO3/maturin#1587
  * Enabled color output for error message
    gh#PyO3/maturin#1591
  * Always set PYO3_PYTHON if interpreter is runnable regardless
    of abi3
    gh#PyO3/maturin#1592
* Sun Apr  9 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.17:
  * Fix wrong EXT_SUFFIX when cross compiling musllinux wheels for
    Python 3.11
    gh#PyO3/maturin#1560
- Drop vendor-update-ahash-dependency.patch
* Wed Mar 29 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.16:
  * Deprecate package.metadata.maturin.name in favor of
    tool.maturin.module-name in pyproject.toml
    gh#PyO3/maturin#1531
* Fri Mar 17 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.15:
  * Add sdist and sccache support to generate-ci command
- Changes in v0.14.14:
  * Add support for Emscripten in generate-ci command
    gh#PyO3/maturin#1484
  * Use default ext_suffix for Emscripten target if not provided in
    PYO3_CONFIG_FILE
    gh#PyO3/maturin#1491
  * Deprecate package.metadata.maturin.data in favor of
    tool.maturin.data in pyproject.toml
    gh#PyO3/maturin#1492
* Tue Feb 21 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.13:
  * maturin develop now looks for a virtualenv .venv in the current
    or any parent directory if no virtual environment is active
    gh#PyO3/maturin#1462
  * Add a new generate-ci command to generate CI configuration
    gh#PyO3/maturin#1456
  * Deprecate --univeral2 in favor of universal2-apple-darwin
    target
    gh#PyO3/maturin#1457
  * Raise an error when Cargo.toml contains removed python package
    metadata
    gh#PyO3/maturin#1471
  * Use extension_name instead of module_name for CFFI extensions
    in develop mode
    gh#PyO3/maturin#1476
- Changes in v0.14.12:
  * Keep dev-dependencies in sdist when there are no path
    dependencies
    gh#PyO3/maturin#1441
- Changes in v0.14.11:
  * Use the extension_name in develop builds
    gh#PyO3/maturin#1416
  * Upgrade pyo3 to 0.18.0
    gh#PyO3/maturin#1417
  * Better error message when normalize path failed
    gh#PyO3/maturin#1432
  * Don't package dev-only path dependencies in sdist
    gh#PyO3/maturin#1435
  * Add a user-friendly panic hook
    gh#PyO3/maturin#1436
* Sat Jan 14 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.10
  * Use module name specified by [package.metadata.maturin]
    gh#PyO3/maturin#1409
* Wed Jan 11 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.9
  * Don't pass MACOSX_DEPLOYMENT_TARGET when query default value
    from rustc
    gh#PyO3/maturin#1395
* Mon Jan  9 2023 Mia Herkt <mia@0x0.st>
- Update to v0.14.8:
  * Add support for packaging multiple pure Python packages
    gh#PyO3/maturin#1378
  * Fallback to sysconfig interpreters for pyo3 bindings
    gh#PyO3/maturin#1381
* Wed Dec 21 2022 Mia Herkt <mia@0x0.st>
- Update to v0.14.7:
  * Update uniffi_bindgen to 0.22.0
    gh#PyO3/maturin#1359
  * Add workspace lock file to sdist as a fallback
    gh#PyO3/maturin#1362
- Changes in v0.14.6:
  * Allow Rust crate to be placed outside of the directory
    containing pyproject.toml
    gh#PyO3/maturin#1347
  * Disallow uniffi bin bindings
    gh#PyO3/maturin#1353
  * Update bundled Python sysconfigs for Linux and macOS
    gh#PyO3/maturin#1355
* Mon Dec 12 2022 Mia Herkt <mia@0x0.st>
- Manually override outdated ahash dependency of chumsky crate
  in vendor tarball to hopefully facilitate reproducible builds
  Adds vendor-update-ahash-dependency.patch
  boo#1206342
- Update to v0.14.5:
  * Support SOURCE_DATE_EPOCH environment variable in wheel building
    gh#PyO3/maturin#1334
  * Fix sdist when all Cargo workspace members are excluded
    gh#PyO3/maturin#1343
- Changes in v0.14.4:
  * Bump sigstore/gh-action-sigstore-python from 0.0.11 to 0.1.0
    gh#PyO3/maturin#1317
  * Refactor Target::get_platform_tag to use standard osname-release-machine fallback representation
    gh#PyO3/maturin#1318
  * Better error message when upload failed with status code 403
    gh#PyO3/maturin#1323
  * Warn about patchelf version requirement
    gh#PyO3/maturin#1327
  * Refactor compile to take cargo targets with bridge model
    gh#PyO3/maturin#1328
* Thu Dec  1 2022 Mia Herkt <mia@0x0.st>
- Update to v0.14.3:
  * Bump MSRV to 1.62.0
    gh#PyO3/maturin#1297
  * CI: Run ruff in lint jobs
    gh#PyO3/maturin#1298
  * Fix build error when required features of bin target isn't
    enabled
    gh#PyO3/maturin#1299
  * Build and publish armv6l wheels for maturin
    gh#PyO3/maturin#1300
  * Fix wrong platform tag when building in i386 docker container
    on x86_64 host
    gh#PyO3/maturin#1301
  * Fix wrong platform tag when building in armv7 docker container
    on aarch64 host
    gh#PyO3/maturin#1303
  * CI: Stop caching test crates target directory
    gh#PyO3/maturin#1302
  * refactor: Use clap_complete_command
    gh#PyO3/maturin#1304
  * Remove human-panic dependency
    gh#PyO3/maturin#1305
  * chore: cargo update to remove rustix 0.35.x
    gh#PyO3/maturin#1307
  * chore: cargo update cargo-zigbuild and cargo-xwin
    gh#PyO3/maturin#1314
* Fri Nov 25 2022 Mia Herkt <mia@0x0.st>
- Update to v0.14.2:
  * Tighten src-layout detection logic
    gh#PyO3/maturin#1282
  * Update cargo_metadata to 0.15.2
    gh#PyO3/maturin#1284
  * Tell people about setting RUST_LOG=maturin=debug when making
    bug reports
    gh#PyO3/maturin#1286
  * Fix generating pep517 sdist for src-layout
    gh#PyO3/maturin#1288
  * Deprecate python-source option in Cargo.toml
    gh#PyO3/maturin#1291
  * Fix auditwheel with read-only libraries
    gh#PyO3/maturin#1292
  * CI: Try nextest double spawn feature
    gh#PyO3/maturin#1294
  * Update wasmtime dependency version to 3.0.0
    gh#PyO3/maturin#1295
- Changes in v0.14.1:
  * Downgrade cargo_metadata to 0.15.0
    gh#PyO3/maturin#1279
* Sun Nov 20 2022 Mia Herkt <mia@0x0.st>
- Update to v0.14.0:
  * Breaking Change: Remove support for specifying python package
  metadata in `Cargo.toml`
  Python package metadata should be specified in the `project`
  section of `pyproject.toml` instead as PEP 621 specifies.
  gh#PyO3/maturin#1200
  * Initial support for shipping bin targets as wasm32-wasi binaries
  that are run through wasmtime
  Note that wasmtime currently only support the five most popular
  platforms and that wasi binaries have restrictions when
  interacting with the host.
  Usage is by setting `--target wasm32-wasi`.
  gh#PyO3/maturin#1107
  * Add support for python first `src` project layout
  gh#PyO3/maturin#1185
  * Add `--src` option to generate src layout for mixed Python/Rust
  projects
  gh#PyO3/maturin#1189
  * Add Python metadata support for `license-file` field of
  `Cargo.toml`
  gh#PyO3/maturin#1195
  * Upgrade to clap 4.0
  This bumps MSRV to 1.61.0.
  gh#PyO3/maturin#1197
  * Remove `workspace.members` in `Cargo.toml` from sdist if there
  isn't any path dependency
  in #[1227](https://github.com/PyO3/maturin/pull/1227)
  * Fix auditwheel `libpython` check on Python 3.7 and older
  versions
  gh#PyO3/maturin#1229
  * Use generic tags when
  `sys.implementation.name` != `platform.python_implementation()`
  Fixes the compatibility tags for Pyston.
  gh#PyO3/maturin#1232
  * Set default macOS deployment target version if
  `MACOSX_DEPLOYMENT_TARGET` isn't specified
  gh#PyO3/maturin#1251
  * Add support for 32-bit x86 FreeBSD target
  gh#PyO3/maturin#1254
  * Add `[tool.maturin.include]` and `[tool.maturin.exclude]` and
  deprecate `[tool.maturin.sdist-include]`
  gh#PyO3/maturin#1255
  * Ignore sdist tar ball instead of error out
  gh#PyO3/maturin#1259
  * Add support for `uniffi` bindings
  gh#PyO3/maturin#1275
* Thu Nov 10 2022 Mia Herkt <mia@0x0.st>
- Update to v0.13.7:
  * Fix macOS LC_ID_DYLIB for abi3 wheels
    gh#PyO3/maturin#1208
  * Pass --locked to Cargo when bootstrap from sdisFix build for Python 3.11 on Windows
    gh#PyO3/maturin#1222
  * Fix build for Python 3.11 on Windows
    gh#PyO3/maturin#1222
* Mon Oct 24 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.13.6:
  - Add cargo-deny integration
  - Fix maturin develop in Windows conda virtual environment
  - Filter out unwanted Cargo target kinds when determine bridge
    model
  - Add maturin develop test case for conda
  - Bump console from 0.15.1 to 0.15.2
  - Bump thiserror from 1.0.36 to 1.0.37
  - [StepSecurity] ci: Harden GitHub Actions
  - Downgrade indicatif to fix build on some 32-bit platforms
  - Allow rustix dependency now that Alpine removed thumb-mode on
    armv7l
  - Bump textwrap from 0.15.0 to 0.15.1
  - Replace pretty_env_logger with tracing-subscriber
  - Include Cargo.lock by default in source distribution
* Thu Sep 29 2022 Mia Herkt <mia@0x0.st>
- Update to v0.13.5
  * Fix resolving crate name bug
    gh#PyO3/maturin#1142
- Changes in v0.13.4:
  * Fix Cargo.toml in new project template
    gh#PyO3/maturin#1109
  * Fix maturin develop on Windows when using Python installed
    from msys2
    gh#PyO3/maturin#1112
  * Fix duplicated Cargo.toml of local dependencies in sdist
    gh#PyO3/maturin#1114
  * Add support for Cargo workspace dependencies inheritance
    gh#PyO3/maturin#1123
  * Add support for Cargo workspace metadata inheritance
    gh#PyO3/maturin#1131
  * Use goblin instead of shelling out to patchelf to get rpath
    gh#PyO3/maturin#1139
- Changes in v0.13.3:
  * Allow user to override default Emscripten settings
    gh#PyO3/maturin#1059
  * Enable --crate-type cdylib on Rust 1.64.0
    gh#PyO3/maturin#1060
  * Update MSRV to 1.59.0
    gh#PyO3/maturin#1071
  * Fix abi3 wheel build when no Python interpreters found
    gh#PyO3/maturin#1072
  * Add zig ar support
    gh#PyO3/maturin#1073
  * Fix sdist build for optional path dependencies
    gh#PyO3/maturin#1084
  * auditwheel: find dylibs in Cargo target directory
    gh#PyO3/maturin#1092
  * Add library search paths in Cargo target directory to rpath in
    editable mode on Linux
    gh#PyO3/maturin#1094
  * Remove default manifest path for maturin sdist command
    gh#PyO3/maturin#1097
  * Fix sdist when pyproject.toml isn’t in the same dir of
    Cargo.toml
    gh#PyO3/maturin#1099
  * Change readme and license paths in pyproject.toml to be
    relative to pyproject.toml
    gh#PyO3/maturin#1100. It’s technically a breaking
  * change, but previously it doesn’t work properly.
  * Add python source files specified in pyproject.toml to sdist
    gh#PyO3/maturin#1102
  * Change sdist-include paths to be relative to pyproject.toml
    gh#PyO3/maturin#1103
* Sun Aug 14 2022 Mia Herkt <mia@0x0.st>
- Update to v0.13.2
  * Add Linux mips64el architecture support
    gh#PyO3/maturin#1023
  * Add Linux mipsel architecture support
    gh#PyO3/maturin#1024
  * Add Linux 32-bit powerpc architecture support
    gh#PyO3/maturin#1026
  * Add Linux sparc64 architecture support
    gh#PyO3/maturin#1027
  * Bump anyhow from 1.0.58 to 1.0.59
    gh#PyO3/maturin#1031
  * Bump serde from 1.0.140 to 1.0.141
    gh#PyO3/maturin#1032
  * Bump clap from 3.2.15 to 3.2.16
    gh#PyO3/maturin#1033
  * Bump tracing from 0.1.35 to 0.1.36
    gh#PyO3/maturin#1035
  * Bump dialoguer from 0.10.1 to 0.10.2
    gh#PyO3/maturin#1034
  * Add PEP 440 local version identifier support
    gh#PyO3/maturin#1037
  * Fix path search upon python3 -m maturin
    gh#PyO3/maturin#1038
  * Update cargo-zigbuild to 0.12.0
    gh#PyO3/maturin#1042
  * Fix inconsistent Cargo.toml and pyproject.toml path handling
    gh#PyO3/maturin#1043
  * Clarify sdist build error due to missing pyproject.toml
    gh#PyO3/maturin#1045
  * Find python module next to pyproject.toml if pyproject.toml
    exists
    gh#PyO3/maturin#1044
  * Add python-source option to [tool.maturin] section of
    pyproject.toml
    gh#PyO3/maturin#1046
  * Deprecate support for specifying python metadata in Cargo.toml
    gh#PyO3/maturin#1048
  * Change python-source to be relative to the file specifies it
    gh#PyO3/maturin#1049
  * Change data to be relative to the file specifies it
    gh#PyO3/maturin#1051
  * Update Pyodide to 0.21.0
    gh#PyO3/maturin#1056
  * Find pyproject.toml in parent directories of Cargo.toml
    gh#PyO3/maturin#1054
  * Deprecate manylinux2010 support
    gh#PyO3/maturin#858
* Wed Jul 27 2022 Mia Herkt <mia@0x0.st>
- Update to v0.13.1
  * Add 64-bit RISC-V support
    gh#PyO3/maturin#1001
  * Run tests on CI with cargo-nextest
    gh#PyO3/maturin#1004
  * Add support for invoking with python3 -m maturin
    gh#PyO3/maturin#1008
  * Consider pyproject.toml features when detecting pyo3
    gh#PyO3/maturin#1014
  * Respect user specified Rust target in maturin develop
    gh#PyO3/maturin#1016
  * Use cargo rustc --crate-type cdylib on Rust nightly/dev channel
    gh#PyO3/maturin#1020
  * Use cargo-nextest in test-alpine
    gh#PyO3/maturin#1021
* Mon Jul 18 2022 Ben Greiner <code@bnavigator.de>
-  Update to v0.13.0
  * Drop python 3.6
    gh#PyO3/maturin#945
  * Add support for building with multiple binary targets by
    @messense in #948
  * Add a --target option to maturin list-python command by
    @messense in #957
  * Add support for using bundled python sysconfigs for PyPy when
    abi3 feature is enabled
    gh#PyO3/maturin#958
  * Filter cargo targets by kind instead of crate_types by
    @messense in #959
  * Don't build sdist by default in maturin build command by
    @messense in #955
  * Add support for cross compiling PyPy wheels when abi3 feature
    is enabled
    gh#PyO3/maturin#963
  * Update actions/checkout and actions/setup-python versions by
    @messense in #965
  * Add --find-interpreter option to build and publish commands by
    @messense in #964
  * Infer target triple from ARCHFLAGS for macOS by @messense in
    [#967]
  * Add bootstrap from sdist test to CI
    gh#PyO3/maturin#968
  * Upload wheel artifacts in bootstrap test for inspection by
    @messense in #971
  * Expose commonly used Cargo CLI options in maturin build command
    gh#PyO3/maturin#972
  * Add support for wasm32-unknown-emscripten target by @messense
    in #974
  * Allow overriding platform release version using env var by
    @messense in #975
  * Don't warn if package not listed in cargo metadata is a
    dependency of Rust std
    gh#PyO3/maturin#976
  * Fix Emscripten CI: Pyodide packages.json was moved to
    repodata.json
    gh#PyO3/maturin#977
  * Emscripten: Use -Z link-native-libraries=no and remove emcc
    wrapper
    gh#PyO3/maturin#978
  * Fix maturin develop for arm64 Python on M1 Mac when default
    toolchain is x86_64
    gh#PyO3/maturin#980
  * Improvements to Emscripten/Pyodide CI
    gh#PyO3/maturin#983
  * Setup Pyodide with nox for easier local testing by @messense in
    [#984]
  * Remove -Zbuild-std for Emscripten target
    gh#PyO3/maturin#986
  * Add --repository option to upload command
    gh#PyO3/maturin#987
  * Only lookup bundled Python sysconfig when interpreters aren't
    specified as file path
    gh#PyO3/maturin#988
  * Align some maturin build options with cargo by @messense in
    [#991]
  * Find CPython upper to 3.12 and PyPy upper to 3.10 by @messense
    in #993
  * Add aliases for maturin build and develop subcommands by
    @messense in #994
  * Update zbus to 1.9.3 to fix GHSA-76w9-p8mg-j927 and
    GHSA-wgrg-5h56-jg27
    gh#PyO3/maturin#996
  * Update to Rust 1.62 for Docker image
    gh#PyO3/maturin#997
  * Upgrade setuptools-rust to 1.4.0
    gh#PyO3/maturin#998
  * Bump openssl-src from 111.21.0+1.1.1p to 111.22.0+1.1.1q by
    @dependabot in #1000
  * Update user guide for the upcoming 0.13 release by @messense in
    [#973]
- Release 0.12.20
  * Fix incompatibility with cibuildwheel for 32-bit Windows in
    [#951]
  * Don't require pip error messages to be utf-8 encoding in #953
  * Compare minimum python version requirement between
    requires-python and bindings crate in #954
  * Set PYO3_PYTHON env var for PyPy when abi3 is enabled in #960
  * Add sysconfigs for x64 Windows PyPy in #962
  * Add support for Linux armv6l in #966
  * Fix auditwheel bundled shared libs directory name in #969
- Release 0.12.19
  * Fix Windows Store install detection in #949
  * Filter Python interpreters by target pointer width on Windows
    in #950
- Release 0.12.18
  * Add support for building bin bindings wheels with multiple
    platform tags in #928
  * Skip auditwheel for non-compliant linux environment
    automatically in #931
  * Fix abi3 wheel build issue when no Python interpreters found on
    host in #933
  * Add Python 3.11 sysconfigs for Linux, macOS and Windows in #934
  * Add Python 3.11 sysconfig for arm64 Windows in #936
  * Add network proxy support to upload command in #939
  * Fix python interpreter detection on arm64 Windows in #940
  * Fallback to py -X.Y when pythonX.Y cannot be found on Windows
    in #943
  * Auto-detect Python Installs from Microsoft Store in #944
  * Add bindings detection to bin targets in #938
- Release 0.12.17
  * Don't consider compile to i686 on x86_64 Windows cross
    compiling in #923
  * Accept -i x.y and -i python-x.y in maturin build command in
    [#925]
- Release 0.12.16
  * Add Linux armv7l python sysconfig in #901
  * Add NetBSD python sysconfig in #903
  * Update 'replace_needed' to reduce total calls to 'patchelf' in
    [#905]
  * Add wheel data support in #906
  * Allow use python interpreters from bundled sysconfig when not
    cross compiling in #907
  * Use setuptools-rust for bootstrapping in #909
  * Allow setting the publish repository URL via
    MATURIN_REPOSITORY_URL in #913
  * Allow stubs-only mixed project layout in #914
  * Allow setting the publish user name via MATURIN_USERNAME in
    [#915]
  * Add Windows python sysconfig in #917
  * Add support for generate-import-lib feature of pyo3 in #918
  * Integrate cargo-xwin for cross compiling to Windows MSVC
    targets in #919
- Fix runtime requirements
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Wed May 11 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.12.15
  * fix: Only set RUSTFLAGS when absolutely neccessary
  * Update rust dependencies
  * Remove unused libs_dir field from PythonInterpreter
  * Remove target field from PythonInterpreter struct
  * Add support for PYO3_CONFIG_FILE
- Update to 0.12.12
  * Change mixed rust/python template project layout
  * Accept multiple values for --interpreter option
  * Update rust dependencies
- Update to 0.12.11
  * Switch back to toml_edit
  * Add -r option as a short alias for --release
- Update to 0.12.10
  * Support pyo3-ffi
  * Migrate Python dependency uiri/toml to tomllib / hukkin/tomli
  * Use dynamic Python minor version for pyo3 bindings based on
    its verison by
  * Update rust dependencies
* Sat Feb 12 2022 Mia Herkt <mia@0x0.st>
- Update to 0.12.9
  * Don't require `pyproject.toml` when cargo manifest is not
    specified
    gh#PyO3/maturin#806
- Changes in 0.12.8
  * Add missing `--version` flag from clap 3.0 upgrade
- Changes in 0.12.7
  * Add support for using `zig cc` as linker for easier cross
    compiling and manylinux compliance
    gh#PyO3/maturin#756
  * Switch from reqwest to ureq to reduce dependencies
    gh#PyO3/maturin#767
  * Fix missing Python submodule in wheel
    gh#PyO3/maturin#772
  * Add support for specifying cargo manifest path in
    pyproject.toml
    gh#PyO3/maturin#781
  * Add support for passing arguments to pep517 command via
    `MATURIN_PEP517_ARGS` env var
    gh#PyO3/maturin#786
  * Fix auditwheel `No such file or directory` error when
    `LD_LIBRARY_PATH` contains non-existent paths
    gh#PyO3/maturin#794
* Mon Jan 31 2022 Mia Herkt <mia@0x0.st>
- Update to 0.12.6
  * Add support for repairing cross compiled linux wheels
  gh#PyO3/maturin#754
  * Add support for `manylinux_2_28` and `manylinux_2_31`
  gh#PyO3/maturin#755
  * Remove existing so file first in `maturin develop` command to
  avoid triggering SIGSEV in running process
  gh#PyO3/maturin#760
* Thu Dec 23 2021 Mia Herkt <mia@0x0.st>
- Update to 0.12.5
  * Fix docs for new and init commands in maturin --help
    gh#PyO3/maturin#734
  * Fix undefined auditwheel policy panic
    gh#PyO3/maturin#740
  * Fix upload::canonicalize_name() regex subst
    gh#PyO3/maturin#741
  * Bump serde from 1.0.130 to 1.0.131
    gh#PyO3/maturin#745
  * Bump sha2 from 0.9.8 to 0.10.0
    gh#PyO3/maturin#746
  * Add Cargo.lock to sdist when --locked or --frozen specified
    gh#PyO3/maturin#749
  * Implement auditwheel repair with patchelf
    gh#PyO3/maturin#742
  * Support pyo3 abi3-py310 feature
    gh#PyO3/maturin#750
- Changes in 0.12.4:
  * Bump anyhow from 1.0.50 to 1.0.51
    gh#PyO3/maturin#717
  * init: new command similar to cargo init
    gh#PyO3/maturin#719
  * Don't package non-path-dep crates in sdist for workspaces
    gh#PyO3/maturin#720
  * Update keyring to 1.0.0
    gh#PyO3/maturin#721
  * Reorganize upload feature
    gh#PyO3/maturin#726
  * Allow pip warnings in maturin develop command
    gh#PyO3/maturin#732
  * Add a Python import hook
    gh#PyO3/maturin#729
- Changes in 0.12.3:
  * Use platform tag from sysconfig.platform on non-portable Linux
    gh#PyO3/maturin#709
  * Warn missing cffi package dependency
    gh#PyO3/maturin#711
  * new: include function example for PyO3 bindings
    gh#PyO3/maturin#713
- Changes in 0.12.2:
  * Add a maturin new command for bootstrapping new projects
    gh#PyO3/maturin#705
  * Add docs for maturin new command
    gh#PyO3/maturin#707
- Changes in 0.12.1:
  * Add support for cross compiling PyPy wheels
    gh#PyO3/maturin#687
  * Add a runnable field to PythonInterpreter
    gh#PyO3/maturin#691
- Changes in 0.12.0:
  * Add PEP 660 support
    gh#PyO3/maturin#648
  * Refactor develop command to act identical to PEP 660 editable
    wheels
    gh#PyO3/maturin#653
  * Bump anyhow from 1.0.44 to 1.0.45
    gh#PyO3/maturin#664
  * Upgrade pyo3 to 0.15 in test crates
    gh#PyO3/maturin#665
  * Fix typos discovered by codespell
    gh#PyO3/maturin#666
  * Add mdbook based user guide
    gh#PyO3/maturin#658
  * Allow building for non-abi3 pypy wheels when the abi3 feature
    is enabled
    gh#PyO3/maturin#678
  * Bump serde_json from 1.0.69 to 1.0.70
    gh#PyO3/maturin#683
  * Bump keyring from 0.10.1 to 0.10.4
    gh#PyO3/maturin#682
- Changes in 0.11.5:
  * Fix typo in Readme
    gh#PyO3/maturin#638
  * Re-export __doc__ in __init__.py for pure Rust project
    gh#PyO3/maturin#639
  * Fix musllinux auditwheel wrongly detects libc forbidden link
    gh#PyO3/maturin#643
  * Fix Win32 Conda Python Interpreters by @formlogic-robert in
    gh#PyO3/maturin#644
  * Upgrade python-pkginfo to 0.5.0
    gh#PyO3/maturin#645
  * Fix cross compilation for Python 3.10
    gh#PyO3/maturin#646
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Fri Oct  1 2021 Mia Herkt <mia@0x0.st>
- Update to 0.11.4
  * Autodetect PyPy executables
    gh#PyO3/maturin#617
  * auditwheel: add `libz.so.1` to whitelisted libraries
    gh#PyO3/maturin#625
  * auditwheel: detect musl libc
    gh#PyO3/maturin#629
  * Fixed Python 3.10 and later versions detection on Windows
    gh#PyO3/maturin#630
  * Install entrypoint scripts in `maturin develop` command
    gh#PyO3/maturin#633
    gh#PyO3/maturin#634
  * Add support for installing optional dependencies in
    `maturin develop` command
    gh#PyO3/maturin#635
  * Fixed build error when `manylinux`/`compatibility` options is
    specified in `pyproject.toml`
    gh#PyO3/maturin#637
- Changes in 0.11.3:
  * Add path option for Python source
    gh#PyO3/maturin#584
  * Add auditwheel support for musllinux
    gh#PyO3/maturin#597
  * `[tool.maturin]` options from `pyproject.toml` will be used
    automatically
    gh#PyO3/maturin#605
  * Skip unavailable Python interpreters from pyenv
    gh#PyO3/maturin#609
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Tue Aug  3 2021 Mia Herkt <mia@0x0.st>
- Update to 0.11.2
  * Use UTF-8 encoding when reading `pyproject.toml`
    gh#PyO3/maturin#588
  * Use Cargo's `repository` field as `Source Code` in project URL
    gh#PyO3/maturin#590
  * Fold long header fields in Python metadata
    gh#PyO3/maturin#594
  * Fix `maturin develop` for PyPy on Unix
    gh#PyO3/maturin#596
* Sun Jul 11 2021 Mia Herkt <mia@0x0.st>
- Update to 0.11.1
  * Fix sdist error when VCS has uncommitted renamed files
    gh#PyO3/maturin#585
  * Add `maturin completions <shell>` command to generate shell
    completions
    gh#PyO3/maturin#586
- Changes in 0.11.0:
  * Add support for reading metadata from PEP 621 project table in
    `pyproject.toml`
    gh#PyO3/maturin#555
  * Users should migrate away from the old
    `[package.metadata.maturin]` table of `Cargo.toml` to this new
    `[project]` table of `pyproject.toml`
  * Add PEP 656 musllinux support
    gh#PyO3/maturin#543
  * `--manylinux` is now called `--compatibility` and supports
    musllinux
  * The pure rust install layout changed from just the shared
    library to a python module that reexports the shared library.
    This should have now observable consequences for users of the
    created wheel expect that `my_project.my_project` is now also
    importable (and equal to just `my_project`)
  * Add support for packaging type stubs in pure Rust project
    layout
    gh#PyO3/maturin#567
  * `Cargo.toml`'s `authors` field is now optional per Rust
    RFC 3052
    gh#PyO3/maturin#573
  * Allow dotted keys in `Cargo.toml` by switch from `toml_edit` to
    `toml` crate
    gh#PyO3/maturin#577
* Sat May 22 2021 Mia Herkt <mia@0x0.st>
- Update to 0.10.6
  * Fix build with the “upload” feature disabled by ravenexp
    gh#PyO3/maturin#548
- Changes in 0.10.5:
  * Add manylinux_2_27 support
    gh#PyO3/maturin#521
  * Add support for Windows arm64 target
    gh#PyO3/maturin#524
  * Always output PEP 600 platform tags
    gh#PyO3/maturin#525
  * Fix missing PyInit_<module_name> warning with Rust submodule
    gh#PyO3/maturin#528
  * Better cross compiling support for PyO3 binding on Unix
    gh#PyO3/maturin#454
  * Fix s390x architecture support
    gh#PyO3/maturin#530
  * Fix auditwheel panic with s390x wheels
    gh#PyO3/maturin#532
  * Support uploading heterogenous wheels by ravenexp
    gh#PyO3/maturin#544
  * Warn about pyproject.toml missing maturin version constraint
    gh#PyO3/maturin#545
* Sat May  8 2021 Mia Herkt <mia@0x0.st>
- Update to 0.10.4
  * Interpreter search now uses python 3.6 to 3.12
    gh#PyO3/maturin#495
  * Consider requires-python when searching for interpreters
    gh#PyO3/maturin#495
  * Support Rust extension as a submodule in mixed Python/Rust
    project  gh#PyO3/maturin#489
* Tue Apr 20 2021 Mia Herkt <mia@0x0.st>
- init, 0.10.3
